@@ -112,6 +112,9 @@ const char *SQLBinder::use(Line *line, ScriptImage *img)
 	char name[128];
 	char dbname[128];
 
+	if(img->isRipple())
+		return "odbc not supported under ripple";
+
 	if(ScriptCommand::getCount(line) > 0)
 		return "command uses keywords, not arguments";
 
