@@ -383,7 +383,12 @@ const char *ScriptCommand::findKeyword(Line *line, const char *keyword)
 
 const char *ScriptCommand::getMember(Line *line)
 {
-	return strchr(line->cmd, '.');
+	const char *cp = strchr(line->cmd, '.');
+
+	if(cp)
+		++cp;
+
+	return cp;
 }
 
 const char *ScriptCommand::getOption(Line *line, unsigned *idx)
