@@ -1437,7 +1437,7 @@ const char *ScriptInterp::getContent(const char *opt)
 		val = getExternal(++opt);
 		if(val)
 		{
-			snprintf(tmp, 11, "%ld", strlen(val));
+			snprintf(tmp, 11, "%ld", (long)strlen(val));
 			return tmp;
 		}
 		sym = mapSymbol(opt);
@@ -1455,7 +1455,7 @@ const char *ScriptInterp::getContent(const char *opt)
 			return tmp;
 		case symCONST:
 		case symNORMAL:
-			snprintf(tmp, 11, "%ld", strlen(sym->data));
+			snprintf(tmp, 11, "%ld", (long)strlen(sym->data));
 			return tmp;
 		case symCOUNTER:
 			snprintf(tmp, 11, "%ld", atol(sym->data));
